@@ -45,18 +45,12 @@ keymap = (
     ("F11", defaultModifierMask, ORCA_MODIFIER_MASK,
     "toggleTableCellReadModeHandler"),
 
-    ("SunF36", defaultModifierMask, ORCA_MODIFIER_MASK,
-    "toggleTableCellReadModeHandler"),
-
     ("f", defaultModifierMask, ORCA_MODIFIER_MASK,
     "readCharAttributesHandler"),
 
     ("h", defaultModifierMask, ORCA_MODIFIER_MASK,
     "enterLearnModeHandler", 1),
 
-    ("h", defaultModifierMask, ORCA_MODIFIER_MASK,
-    "enterListShortcutsModeHandler", 2),
-
     ("q", defaultModifierMask, ORCA_MODIFIER_MASK,
     "shutdownHandler"),
 
