@@ -29,18 +29,19 @@ __license__   = "LGPL"
 
 import pyatspi
 
+import orca.cmdnames as cmdnames
 import orca.debug as debug
 import orca.scripts.default as default
 import orca.keybindings as keybindings
 import orca.input_event as input_event
 import orca.braille as braille
+import orca.messages as messages
 import orca.orca as orca
 import orca.orca_state as orca_state
 import orca.speech as speech
 import orca.speechserver as speechserver
 import orca.settings as settings
 import orca.settings_manager as settings_manager
-from orca.orca_i18n import _
 
 from .formatting import Formatting
 from .speech_generator import SpeechGenerator
@@ -120,7 +121,7 @@ class Script(default.Script):
         self.inputEventHandlers["sayAllHandler"] = \
             input_event.InputEventHandler(
                 Script.sayAll,
-                _("Speaks entire document."))
+                cmdnames.SAY_ALL)
 
     def isActivatableEvent(self, event):
         """Returns True if the given event is one that should cause this
@@ -325,10 +326,7 @@ class Script(default.Script):
         line = self.utilities.adjustForRepeats(string)
 
         if self.utilities.speakBlankLine(obj):
-            # Translators: "blank" is a short word to mean the
-            # user has navigated to an empty line.
-            #
-            speech.speak(_("blank"), None, False)
+            speech.speak(messages.BLANK, None, False)
         else:
             speech.speak(line, None, False)
 
