@@ -119,102 +119,6 @@ class Utilities(script_utilities.Utilities):
 
         return False
 
-    def isWizard(self, obj):
-        """Returns True if this object is, or is within, a wizard.
-
-        Arguments:
-        - obj: the Accessible object
-        """
-
-        # The Setup Assistant is a frame whose child is a panel. That panel
-        # holds a bunch of other panels, one for each stage in the wizard.
-        # Only the active stage's panel has STATE_SHOWING. There is also
-        # one child of ROLE_FILLER which holds the buttons.
-        #
-        window = self.topLevelObject(obj) or obj
-        if window and window.getRole() == pyatspi.ROLE_FRAME \
-           and window.childCount and window[0].getRole() == pyatspi.ROLE_PANEL:
-            allPanels = panelsNotShowing = 0
-            for child in window[0]:
-                if child.getRole() == pyatspi.ROLE_PANEL:
-                    allPanels += 1
-                    if not child.getState().contains(pyatspi.STATE_SHOWING):
-                        panelsNotShowing += 1
-            if allPanels - panelsNotShowing == 1 \
-               and window[0].childCount - allPanels == 1:
-                return True
-
-        return False
-
-    def isWizardNewInfoEvent(self, event):
-        """Returns True if the event is judged to be the presentation of
-        new information in a wizard. This method should be subclassed by
-        application scripts as needed.
-
-        Arguments:
-        - event: the Accessible event being examined
-        """
-
-        if event.source.getRole() == pyatspi.ROLE_FRAME \
-           and (event.type.startswith("window:activate") \
-                or (event.type.startswith("object:state-changed:active") \
-                    and event.detail1 == 1)):
-            return self.isWizard(event.source)
-
-        elif event.source.getRole() == pyatspi.ROLE_PANEL \
-             and event.type.startswith("object:state-changed:showing") \
-             and event.detail1 == 1 \
-             and not self.isSameObject(event.source, 
-                                       self._script.lastSetupPanel):
-            rolesList = [pyatspi.ROLE_PANEL,
-                         pyatspi.ROLE_PANEL,
-                         pyatspi.ROLE_FRAME]
-            if self.hasMatchingHierarchy(event.source, rolesList):
-                return self.isWizard(event.source)
-
-        return False
-
-    def unrelatedLabels(self, root):
-        """Returns a list containing all the unrelated (i.e., have no
-        relations to anything and are not a fundamental element of a
-        more atomic component like a combo box) labels under the given
-        root.  Note that the labels must also be showing on the display.
-
-        Arguments:
-        - root the Accessible object to traverse
-
-        Returns a list of unrelated labels under the given root.
-        """
-
-        labels = script_utilities.Utilities.unrelatedLabels(self, root)
-        for i, label in enumerate(labels):
-            if not label.getState().contains(pyatspi.STATE_SENSITIVE):
-                labels.remove(label)
-            else:
-                try:
-                    text = label.queryText()
-                except:
-                    pass
-                else:
-                    attr = text.getAttributes(0)
-                    if attr[0]:
-                        [charKeys, charDict] = \
-                            self.stringToKeysAndDict(attr[0])
-                        if charDict.get('weight', '400') == '700':
-                            if self.isWizard(root):
-                                # We've passed the wizard info at the top,
-                                # which is what we want to present. The rest
-                                # is noise.
-                                #
-                                return labels[0:i]
-                            else:
-                                # This label is bold and thus serving as a
-                                # heading. As such, it's not really unrelated.
-                                #
-                                labels.remove(label)
-
-        return labels
-
     #########################################################################
     #                                                                       #
     # Utilities for working with the accessible text interface              #
